@@ -294,7 +294,7 @@ class VideoAgent(aeidon.Delegate):
         rows = page.view.get_selected_rows()
         pos = page.project.subtitles[rows[-1]].end_seconds
         offset = gaupol.conf.video_player.context_length
-        self.player.seek(pos - offset)
+        self.player.seek(max(pos - offset, 0))
 
     @aeidon.deco.export
     def _on_seek_selection_start_activate(self, *args):
@@ -303,7 +303,7 @@ class VideoAgent(aeidon.Delegate):
         rows = page.view.get_selected_rows()
         pos = page.project.subtitles[rows[0]].start_seconds
         offset = gaupol.conf.video_player.context_length
-        self.player.seek(pos - offset)
+        self.player.seek(max(pos - offset, 0))
 
     def _on_seekbar_change_value(self, seekbar, scroll, value, data=None):
         """Seek to specified position in video."""
